==> haskell-assoc-1.0.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-7N0nK22dMp5J6nIxsx6mUe
key:                  assoc-1.0.2-7N0nK22dMp5J6nIxsx6mUe
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  32720b4c213eacbd2067d7327adf9afc
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-9.0.1/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-7N0nK22dMp5J6nIxsx6mUe
depends:
    base-4.15.0.0 bifunctors-5.5.11-3MgHowlkzBNDa84Pzdaw4w
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-assoc-1.0.2-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-assoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 assoc
version:              1.0.2
visibility:           public
id:                   assoc-1.0.2-L2qZPfVmSwT89Mh08lZ6en
key:                  assoc-1.0.2-L2qZPfVmSwT89Mh08lZ6en
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             swap and assoc: Symmetric and Semigroupy Bifunctors
description:
    Provides generalisations of
    @swap :: (a,b) -> (b,a)@ and
    @assoc :: ((a,b),c) -> (a,(b,c))@
    to
    @Bifunctor@s supporting similar operations (e.g. @Either@, @These@).

category:             Data
abi:                  242984f1a61af15782b541388a87744d
exposed:              True
exposed-modules:      Data.Bifunctor.Assoc Data.Bifunctor.Swap
import-dirs:          /usr/lib/ghc-9.0.1/site-local/assoc-1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/assoc-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/assoc-1.0.2
hs-libraries:         HSassoc-1.0.2-L2qZPfVmSwT89Mh08lZ6en
depends:
    base-4.15.0.0 bifunctors-5.5.11-6LpscOqvpXFF7to3ER7bDY
    tagged-0.8.6.1-FL843C40q4d1DeuwYADr25

haddock-interfaces:   /usr/share/doc/haskell-assoc/html/assoc.haddock
haddock-html:         /usr/share/doc/haskell-assoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
